<h1>Cancel subscription notification</h1>

<p>Use link below to cancel subscrpition.</p>

<a href="https://{{ host }}{% url 'stripe-subscription:cancel-confirm' token %}">https://{{ host }}{% url 'stripe-subscription:cancel-confirm' token %}</a>
