# Generated by Django 3.1.1 on 2021-03-19 02:26

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('stripe_subscription', '0002_auto_20210319_0226'),
    ]

    operations = [
        migrations.AddField(
            model_name='plan',
            name='trial_days',
            field=models.IntegerField(default=3),
        ),
    ]
