# Generated by Django 3.1.1 on 2021-03-19 02:26

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('stripe_subscription', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='plan',
            name='deep_link',
            field=models.URLField(blank=True, max_length=500, null=True),
        ),
        migrations.AddField(
            model_name='subscription',
            name='quiz',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='plan',
            name='recurring_interval',
            field=models.CharField(choices=[('week', 'Week'), ('month', 'Month'), ('year', 'Year')], max_length=255),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='is_active',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterUniqueTogether(
            name='subscription',
            unique_together={('user', 'plan')},
        ),
    ]
